158,514 Commits over 4,566 Days - 1.45cph!
gulls transition to shaders later after takeoff
more consistent seeding for randomness
Bunch of LOD optims:
- The budget is now checked mid cell, if a dense cell exceeds the budget we pause and resume on the next frame. Fixes big spikes for large cells
- Camera and player positions are read once per frame instead of by every LOD member
- Static LOD members cache their grid position
- Mesh and renderer LODs skip their update while their distance stays between the same LOD distances
Editor profiling, walking around a big base, LODGrid p99 frame: ~15ms -> ~1ms (max budget)
Updated crow flock model with far lod
Fix editor asset loading on case sensitive filesystems
Migrate third-party packages to `EntityId` in preparation for Unity 6.7
LODs and collision for each damage stage of Lighthouse Lamp. Individual damage state prefab setup.
Fixed remaining missed materials.
▋ ▌▅▆▆█ ▌▅▊▆ ▇▍▊▄▌▄▍▌▇▇▅▍▊▍▅█▊▅▇▍▄▌▋▉
▅▉█▄▌▉█ ▊▉▌▊▅▄▉▅█ ▉▆▆▍▄▋█▊ ▄▌▌
New CullWhenInside combined approach with jarryds and my original fixes joined together
- Keep the work queue with its own budget
- Bushes are only queued when foundations change
Uzi 3p: fix stock deploy after weapon swap + stock swing on holster
- player + world controllers fall back to the stock deploy if the stock flag arrives late
- world stock deploy holds idle_stock instead of playing the swing
- world animator keeps state on disable so holstering doesn't replay the swing
merge from main
stomp local CullWhenInside changes
Refactor, more generic, reusable.
Add additional experimental wall rules (wall->window, wall->wall frame, doorway->wall frame).
Renovation saw now uses a context based radial menu, showing available renovation/cut options for target construction.
Fixed the volumetric light beam clipping the camera when using the miner hat
merge from saveload_eventschedule
Saveload the hours remaining for event schedule events
Fixes for example cargo ship being just about to spawn, server restarts and now you have to wait the full cooldown again
merge from scrap_king_building_skin (lightened interior concrete)
scrap king - concrete texture tweaks
Fix PersistentObjectWorkQueues stalling in the editor with skip domain reload
Add the attribute to some missing places
removed unnecessary files
██ ▆▍▅▄▄▄ ▇▇▋▌▍▄ ▌▊▍▌ ▊▉▌ █▋▄▇▅▋▅▊ █▅█▉ ▄▉ ▄▋▄▌▌▄▅ ▍▄▋ ▌▌▅▍▊█▄▆▅▊
merge from viewmodel_skinning_update
Remove split shadow culling for now
merge from pedalbikewheelfix
merge from procgen_fix_monument_spacing
merge from procgen_fix_canyon_tunnels
small games wooden table;
- game textures
- material updated
merge from carvedpumpkin_lodfix
merge from cinelightmeshfix
merge from planter_guide_fixes
Merge from probe_cameratype_fix
During probe rendering set cameraType to reflection only during RRP render to stop unintended rendering
Optimize refreshing links after block is spawned & killed
- refreshing neighbors was causing faces to be queued multiple times, will now only queue each face at most once after changes
Apply the new collision ref collision to biofuel generator (just for testing)
Mark any mesh used for collision baking as ExcludeFromBundles so it won't be added to the build
Fix BoxColliderBake component having different serialization layout when building
Switch the tests with doors from unit tests -> automated tests
- was throwing errors after the navmesh was changed, figured may as well make automated
Merge from livestock_animals
Add missing shears effects
Update item description
Merge from CullWhenInside_vis_improvement
mainisland_roaming_scientistboats -> main
Updated CullWhenInside to run in a PersistentObjectWorkQueue with a 1s min lap time so it can't update too often. Has a 0.01ms budget so it generally can only process one a frame
Reduced LODManager budget to 0.05ms from 0.1ms
A large portion of LODManager ChangeLOD calls were spending all of their time in CullWhenInside due to it's expensive Vis check, by moving that out we should have more responsive LODs even with a smaller budget
Introduces a small delay when building over bushes, but we gain 0.05ms overall